<h1>Rando ALgo</h1>
A python package that allows users to get random algorithm questions to practice. 
<h2>Usage</h2>
<p>To use Rando Algo, user can install it as a pypi package.</p>
<p>To install this package go to <a href= https://pypi.org/manage/projects/>alt='Link to RandoAlgo package</a>.
You can also run pip install randoalgo-rjay on your command line.</p>
<p>To use app on Commandline, enter <b>RandoAlgo</b>
<p>Users must have request and beautifulsoup4 libraries installed to use app<p>
<p>Users have to have login and enter in a password, after this they can now enter a number to practice algorithm questions.</p>
<p>User can play as many times as they want to but if they no longer wish to continue, they can exit.</p>
